@@ -10,18 +10,18 @@ from itksn.core import EnumStr
 
 def test_enumstr():
     myenum = EnumStr(Bytes(2), itsaa=b"aa", itsbb=b"bb", itsyy=b"yy")
-    assert myenum.parse(b"yy").intvalue == b"yy"
+    assert myenum.parse(b"yy").bytevalue == b"yy"
     assert myenum.parse(b"yy") == "itsyy"
-    assert myenum.parse(b"xx").intvalue == b"xx"
-    assert myenum.parse(b"xx") == ""
+    assert myenum.parse(b"xx").bytevalue == b"xx"
+    assert not myenum.parse(b"xx")
 
 
 def test_parse_example1():
     parsed = itksn.parse(b"20Uxxyynnnnnnn")
     assert parsed.atlas_project == "atlas_detector"
     assert parsed.system_code == "phaseII_upgrade"
-    assert parsed.project_code == ""
-    assert parsed.subproject_code == ""
+    assert not parsed.project_code
+    assert parsed.subproject_code == "yy"
     assert parsed.identifier == b"nnnnnnn"
 
 
@@ -30,7 +30,7 @@ def test_parse_example2():
     assert parsed.atlas_project == "atlas_detector"
     assert parsed.system_code == "phaseII_upgrade"
     assert parsed.project_code == "inner_pixel"
-    assert parsed.subproject_code == ""
+    assert not parsed.subproject_code
     assert parsed.identifier == b"nnnnnnn"
 
 
@@ -40,7 +40,7 @@ def test_parse_fe_wafer():
     assert parsed.system_code == "phaseII_upgrade"
     assert parsed.project_code == "pixel_general"
     assert parsed.subproject_code == "FE_chip_wafer"
-    assert parsed.identifier.batch_number == "CROC"
+    assert parsed.identifier.batch_number == "ITkpix_v2"
     assert parsed.identifier.number == b"123456"
 
 
